-- box2D new box shape+body
function box(x, y, w, h, m, r)
   local o = {}
   r = r or 0
   o.body  = love.physics.newBody(world, x, y, m, r)
   o.shape = love.physics.newRectangleShape(o.body, 0, 0, w, h)
   o.color = {math.random(256), math.random(256), math.random(256)}
   return o
end

-- draw box
function dr(s)
   love.graphics.setColor(s.color[1], s.color[2], s.color[3])
   love.graphics.polygon("fill", s.shape:getPoints())
end

function love.load()
   width = 650
   height = 650

   world = love.physics.newWorld(-width, -height, width, height)
   world:setGravity(0, 50)
   world:setMeter(64)
   
   -- why do i need to put width*2 to stretch the ground to the entire window?
   -- same for height wich currently doesn't fill the bottom of the window
   ground = box(0, height-20, width*2, 20, 0)
   
   torso = box(width/2, height/2, 20, 100, 50, .5)
   front = box(width/2, height/2+80, 15, 80, 15, .2)
   back  = box(width/2, height/2+80, 15, 80, 15, .1)

   -- one joint for each leg
   -- x,y parameters are coordinates for the axe of rotation i guess?
   j1 = love.physics.newRevoluteJoint(front.body, torso.body, width/2+10, height/2+90)
   j2 = love.physics.newRevoluteJoint(back.body,  torso.body, width/2+10, height/2+90)

   -- suppress some collision
   j1:setCollideConnected(false)
   j2:setCollideConnected(false)
   
   ground.shape:setCategory(2)
   front.shape:setCategory(1)
   back.shape:setCategory(1)
   front.shape:setMask(1)
   back.shape:setMask(1)


   nb_up = 0
   nb_down = 0


   love.graphics.setMode(width, height, false, true, 0)
end

function love.quit()
   return false
end

function love.keypressed(key, unicode)
   local d
   local v
   local a = 100
   


   if key == 'up' then
      nb_up = nb_up + 1
      d = math.random()
      front.body:setAngularVelocity(a*d)
      
      d = math.random()
      back.body:setAngularVelocity(-a*d)
   
   elseif key == 'down' then
      nb_down = nb_down + 1
      d = math.random()
      front.body:setAngularVelocity(-a*d)
      
      d = math.random()
      back.body:setAngularVelocity(a*d)

   elseif key == 'escape' then
      love.event.push("q")
   end
end

function love.keyreleased(key)
   if key == 'up' or key == 'down' then
      front.body:setAngularVelocity(0)
      back.body:setAngularVelocity(0)
   end
end



function love.update(dt)
   world:update(dt)
end


function love.draw()
   dr(ground)
   dr(torso)
   dr(front)
   dr(back)

   local str
   str = string.format("(%d) up at %.3f", nb_up, front.body:getAngularVelocity())
   love.graphics.print(str, 0, 0)
   str = string.format("(%d) down at %.3f", nb_down, back.body:getAngularVelocity())
   love.graphics.print(str, 0, 20)
   
end
